`PyCBC <http://pycbc.org>`_ is a software package used to explore astrophysical sources of gravitational waves. It contains algorithms to analyze gravitational-wave data from the LIGO and Virgo detectors, detect coalescing compact binaries, and measure the astrophysical parameters of detected sources. PyCBC was used in the `first direct detection of gravitational waves <https://journals.aps.org/prl/abstract/10.1103/PhysRevLett.116.061102>`_ and is used in the flagship analysis of LIGO and Virgo data.

PyCBC is developed collaboratively and lead by a team of LIGO scientists with the aim to build accessible tools for gravitational-wave data analysis. One of the easiest ways to get a full software environment is by `downloading one of our docker images. <http://pycbc.org/pycbc/latest/html/docker.html>`_

Some interactive examples using portions of the PyCBC library are also hosted as jupyter notebooks on Microsoft Azure. `Feel free to give them a try. <https://notebooks.azure.com/nitz/libraries/pycbc>`_  You can also explore the `full documentation pages <http://pycbc.org/pycbc/latest/html/index.html>`_ or the `source code on GitHub. <https://github.com/ligo-cbc/pycbc>`_ 

If you use PyCBC in scientific publications, please see our `citation guidelines. <http://pycbc.org/pycbc/latest/html/credit.html>`_ 
